<?php

# Default css sheet for FitGallery 0.90
# random multicolor background, red border boxes
# under public domain

header('Content-type: text/css');
echo '
div.figure
{
  float: left;
  border: thin red solid;
  margin: 0.3em;
  padding: 0.3em;
  text-align: center;
}
p.caption
{
  font-size: smaller;
  text-indent: 0;
  white-space: nowrap;
}
p.clear,p.nav,form.tpp
{ 
  clear: left;
  text-align: center;
}
p.normal,p.clear,h2.normal,h3.normal,h4.normal
{ 
  text-align: center;
}
img.thumbnail,img.exif_thumb,img.w3c
{
  border-style: none;
}
a.texto
{
  color: #0000ff;
}

a.texto:visited       
{               
  color: #660066;
}               

a.texto:active
{
  color: #ff0000;
}

a.texto:hover
{
  color: #0000ff;
  background: #ffffcc;
}
table.table_exif
{
  margin: auto;
  text-align: center;
}
tr.table_header
{
  font-size: large;
  text-align: center;
}
td.table_item
{
  border: thin red solid;
  text-align: center;
}
body
{
';
if (mt_rand(0,1)) $c_r="d";
else $c_r="f";
if (mt_rand(0,1)) $c_g="d";
else $c_g="e";
if (mt_rand(0,1)) $c_b="d";
else $c_b="e";
echo '  background: #'.$c_r.'0'.$c_g.'0'.$c_b.'0; 
  color: #000000;
}';

?>
